function [fire, transition] = tEvents_pre(transition)

global global_info

%%%%%% enabled transition is "tEvents"
ct = current_time();

%%%%%%%%%%%%%%%%% scan the events %%%%%%%%%%%%%%%%%
% if all the events are covered 
if ge(global_info.events_index, size(global_info.EVENTS, 2))
    fire = 0; return
end

% check the time for upcoming event
next_event_time = global_info.EVENTS{global_info.events_index};
if lt(ct, next_event_time)
    fire = 0; return % time for next event has not come yet    
end

prnCommunity();

fprintf('\n\n');
disp('%%%%%%%%%%%%%%%%%           %%%%%%%%%%%%%%%%%');
disp('%%%%%%%%%%%%%%%%% NEW EVENT %%%%%%%%%%%%%%%%%');
disp('%%%%%%%%%%%%%%%%%           %%%%%%%%%%%%%%%%%');
disp(['current time:  ', num2str(ct)]);


% next event is to happen
global_info.events_index = global_info.events_index + 1;
event_type = global_info.EVENTS{global_info.events_index};

switch event_type 
    case 'Marry'
        % this event stream has 3 info. 
        %      E.g.: 'Marry', 'Olivia', 'Robert'  
        global_info.events_index = global_info.events_index + 1; 
        woman = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        man = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        
        % pass only 'married' as the output token color
        % the other two pieces of info ('Olivia', 'Robert') wil be 
        % passed to tMarry via "global_info.MARRIED_COUPLE"
        global_info.MARRIED_COUPLE.woman = woman; 
        global_info.MARRIED_COUPLE.man = man;
        tokIDperson = tokenAnyColor('pCommunity',1,{woman});
        tokIDgroom = tokenAnyColor('pCommunity',1,{man});
        transition.selected_tokens = [tokIDperson, tokIDgroom];
        transition.new_color = 'married';
        transition.override = 1;   
        fire = all([tokIDperson, tokIDgroom]);

    case 'Death'
        % this event stream has 2 info. E.g.: 'Death', 'Michael'
        global_info.events_index = global_info.events_index + 1; 
        deadperson = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        
        % pass only 'dead' as the output token color
        % the other piece of info (e.g. 'Micheal') wil be 
        % passed to tDead via "global_info.DEAD"
        global_info.DEAD = deadperson;
        tokID1 = tokenAnyColor('pCommunity',1,{deadperson});
        tokID2 = tokenColorless('pCommunity',1); 
        transition.selected_tokens = [tokID1 tokID2];
        transition.new_color = 'dead';
        transition.override = 1;   
        fire = all([tokID1 tokID2]);
        
    case 'Birth'
        % this event stream has 4 pieces of info:  
        %    E.g. 'Birth', 'Sophia', 'Rockson', 'Male'
        global_info.events_index = global_info.events_index + 1; 
        mum = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        baby_name = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        baby_gender = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1;         
        
        % pass only 'born' as the output token color
        % the other piece of info (e.g. 'Sophia', 'Rockson', 'Male') 
        % wil be passed to tBirth via "global_info.BIRTH"
        global_info.BIRTH.mum = mum; 
        global_info.BIRTH.baby_name = baby_name;
        global_info.BIRTH.baby_gender = baby_gender;
        tokID1 = tokenAnyColor('pCommunity',1,{mum});
        tokID2 = tokenColorless('pCommunity',1);         
        transition.selected_tokens = [tokID1 tokID2];
        transition.new_color = 'born';
        fire = all([tokID1 tokID2]);      
   
    case 'Divorce'
        % this event stream has 3 pieces of info: E.g.:
        %      'Divorce','Olivia', 'Robert',
        global_info.events_index = global_info.events_index + 1; 
        woman = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 
        man = global_info.EVENTS{global_info.events_index};
        global_info.events_index = global_info.events_index + 1; 

        % pass only 'divorced' as the output token color
        % the other piece of info (e.g. 'Olivia', 'Robert') 
        % wil be passed to tDivorce via "global_info.DIVORCE"
        global_info.DIVORCE.woman = woman; 
        global_info.DIVORCE.man = man; 
        tokIDwoman = tokenAnyColor('pCommunity',1,{woman});
        tokIDman = tokenAnyColor('pCommunity',1,{man});
        transition.selected_tokens = [tokIDwoman, tokIDman];
        transition.new_color = {woman, man, 'divorced'};
        transition.override = 1;   
        fire = all([tokIDwoman, tokIDman]);        

    otherwise
        disp('Unknown method.')
        fire = 0;
end
